==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
var SlowStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SlowStochasticOscillatorIndicator, _super);
    function SlowStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    SlowStochasticOscillatorIndicator.prototype.get_up = function () {
        return new SlowStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.get_u2 = function () {
        return SlowStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "va", {
        get: function () {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.vb));
        },
        set: function (a) {
            this.h(SlowStochasticOscillatorIndicator.vb, a);
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.uv = function () {
        return this.va;
    };
    SlowStochasticOscillatorIndicator.prototype.u4 = function (a) {
        this.va = a;
    };
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.vb = StrategyBasedIndicator.u7(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { SlowStochasticOscillatorIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
var SlowStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SlowStochasticOscillatorIndicator, _super);
    function SlowStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    SlowStochasticOscillatorIndicator.prototype.get_yy = function () {
        return new SlowStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.get_zb = function () {
        return SlowStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "zj", {
        get: function () {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.zk));
        },
        set: function (a) {
            this.h(SlowStochasticOscillatorIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.y4 = function () {
        return this.zj;
    };
    SlowStochasticOscillatorIndicator.prototype.zd = function (a) {
        this.zj = a;
    };
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.zk = StrategyBasedIndicator.zg(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { SlowStochasticOscillatorIndicator };
